#!/bin/sh

# bb-cpu.sh
#
# BIG BROTHER MONITORING SCRIPT
# Sean MacGuire - BB4 Technologies
# Version 1.5a
# Aug 24th, 2000
#
# This program is Copyright (c) 1997-2000
# BB4 Technologies Inc
# All Rights Reserved
#
# echo "***** BBHOME IS SET TO $BBHOME"
# echo "***** BBTMP IS SET TO $BBTMP"

if test ! "$BBTMP"                      # GET DEFINITIONS IF NEEDED
then
	 # echo "*** LOADING BBDEF ***"
        . $BBHOME/etc/bbdef.sh          # INCLUDE STANDARD DEFINITIONS
fi

if test ! "$MACHINEDOTS"		# THIS SHOULD ALREADY BE SET...
then
	# Setup the name of the local host
	# Save a version of the machine name with '.' 
	# instead of ',', if any are there
	MACHINEDOTS=`echo $MACHINE | $SED 's/,/\./g'`
	if [ "$FQDN" != "TRUE" ]
	then
		OLDIFS=$IFS
		IFS='.'
		set $MACHINEDOTS >/dev/null
		IFS=$OLDIFS
		MACHINEMASK="${1}"
	else
		MACHINEMASK="${MACHINEDOTS}"
	fi
	export MACHINEDOTS MACHINEMASK
fi

#=====================================================================
# CPU TEST AND UPTIME WARNINGS
# AUTOMATIC WARNING IF THE SYSTEM IS UP FOR LESS THAN 1 HOUR
#=====================================================================
#
# echo "*** CPU TEST ***"
set `$UPTIME`

echo $3 | $GREP "," > /dev/null 2>&1
if test "$?" = 0
then
	UP=`echo $3 | $SED "s/,//"`
else
	UP=`echo $3 $4 | $SED "s/,//"`
fi

shift;shift;shift;shift;

ARG=`$EXPR $# - 2`			# 5 MINUTE LOAD AVERAGE
COUNT=1
while test "$COUNT" -le "$ARG"
do
	shift;
	COUNT=`$EXPR $COUNT + 1`
done

AVG=`echo $1 | $SED "s/\,//g" | $SED "s/\.//" `
AVG=`$EXPR $AVG + 0`
# echo "LOAD AVERAGE: $AVG"

LINE="LOAD AVG on $MACHINE is ${AVG}"

if test "$AVG" -ge "$CPUPANIC"
then
	COLOR="red"
elif test "$AVG" -ge "$CPUWARN"
then
	COLOR="yellow"
else	
	COLOR="green"
fi

# echo "*** PS COMMAND $PS ***"

$PS > $BBTMP/bb.$$			# GET A PS LISTING
P=`$CAT $BBTMP/bb.$$ | $WC`		# NUMBER OF PROCESSES
P=`echo $P`
U=`$WHO | $WC`				# GET NUMBER OF USERS
U=`echo $U`

#
# AUTOMATIC WARNING IF A SYSTEM HAS BEEN UP LESS THAN AN HOUR
# THIS WILL HELP US NOTICE SPONTANEOUS REBOOTS!
#
# Mark yellow only if non red already
# Thanks to  jim <jjg@disasters.interactive8.com>

echo $UP | $GREP "min" > /dev/null 2>&1
if test "$?" = "0"
then
	if test "$COLOR" != "red"
	then
		COLOR="yellow"
	fi
	LINE="Warning: Machine recently rebooted
$LINE"
fi

#
# HAS THIS MACHINE BEEN UP SO LONG IT NEEDS TO BE REBOOTED?
# IF NOT NECESSARY, DON'T SET BBTOOMANYDAYSUP IN bbdef.sh
# Thanks to jim <jjg@disasters.interactive8.com>

if test -n "$BBTOOMANYDAYSUP"
then
        echo $UP | $GREP "day" > /dev/null 2>&1
        if test "$?" = "0"
        then
                NUMDAYS=`echo $UP | $AWK '{print $1}'`
                if test "$NUMDAYS" -gt "$BBTOOMANYDAYSUP"
                then
                        if test "$COLOR" != "red"
                        then
                                COLOR="yellow"
                        fi
                        LINE="Warning: This machine has been up for $NUMDAYS days,
which is greater than $BBTOOMANYDAYSUP, the number of days (BBTOOMANYDAYSUP)
you have specified as when a machine should be rebooted.
$LINE"
                fi
        fi
fi

#
# NOW SEND THIS INFORMATION TO THE BIG BROTHER DISPLAY UNIT
#
$BB $BBDISP "status $MACHINE.cpu $COLOR `date` up: $UP, $U users, $P procs, load=${AVG}
$LINE"

$RM -f $BBTMP/bb.$$
